@@ -549,12 +549,11 @@ static void post_jail_init(char *unused_name, char **unused_argv)
 static void scache_post_accept(VSTREAM *stream, char *unused_name,
 			           char **unused_argv, HTABLE *unused_table)
 {
+
     /*
-     * Announce the protocol. Allow lazy clients to receive this together
-     * with the server's response to the client request, but also allow
-     * greedy clients to detect a service mismatch early.
+     * Announce the protocol.
      */
-    attr_print(stream, ATTR_FLAG_MORE,
+    attr_print(stream, ATTR_FLAG_NONE,
 	       SEND_ATTR_STR(MAIL_ATTR_PROTO, MAIL_ATTR_PROTO_SCACHE),
 	       ATTR_TYPE_END);
     (void) vstream_fflush(stream);
