@@ -213,7 +213,8 @@ static void showq_report(VSTREAM *client, char *queue, char *id,
 		arrival_time = atol(start);
 	    break;
 	case REC_TYPE_SIZE:
-	    if (msg_size_ok == 0) {
+	    /* Maildrop files may have a preliminary SIZE record. */
+	    if (msg_size_ok == 0 && strcmp(queue, MAIL_QUEUE_MAILDROP) != 0) {
 		msg_size_ok = (start[strspn(start, "0123456789 ")] == 0
 			       && (msg_size = atol(start)) >= 0);
 		if (msg_size_ok == 0) {
@@ -228,6 +229,7 @@ static void showq_report(VSTREAM *client, char *queue, char *id,
 	    if (*start == 0)
 		start = var_empty_addr;
 	    quote_822_local(printable_quoted_addr, start);
+	    /* For consistency with REC_TYPE_RCPT below. */
 	    printable(STR(printable_quoted_addr), '?');
 	    if (sender_seen++ > 0) {
 		msg_warn("%s: duplicate sender address: %s "
@@ -257,6 +259,7 @@ static void showq_report(VSTREAM *client, char *queue, char *id,
 	    if (*start == 0)			/* can't happen? */
 		start = var_empty_addr;
 	    quote_822_local(printable_quoted_addr, start);
+	    /* For consistency with recipients in bounce logfile. */
 	    printable(STR(printable_quoted_addr), '?');
 	    if (dup_filter == 0
 	      || htable_locate(dup_filter, STR(printable_quoted_addr)) == 0)
@@ -363,7 +366,7 @@ static void showq_service(VSTREAM *client, char *unused_service, char **argv)
     /*
      * Protocol identification.
      */
-    (void) attr_print(client, ATTR_FLAG_MORE,
+    (void) attr_print(client, ATTR_FLAG_NONE,
 		      SEND_ATTR_STR(MAIL_ATTR_PROTO, MAIL_ATTR_PROTO_SHOWQ),
 		      ATTR_TYPE_END);
 
