@@ -514,8 +514,7 @@ static int smtp_get_effective_tls_level(DSN_BUF *why, SMTP_STATE *state)
 	pol_stats_revert(state->tls_stats);
 	if (state->reqtls_level > SMTP_REQTLS_POLICY_ACT_DISABLE)
 	    smtp_tls_stat_activate_reqtls(state->tls_stats,
-					  SMTP_TLS_STAT_NAME_REQTLS,
-					  POL_STAT_ENF_FULL);
+					  SMTP_TLS_STAT_NAME_REQTLS);
     }
 
     /*
