@@ -268,16 +268,22 @@ static int new_client_session_cb(SSL *ssl, SSL_SESSION *session)
 	msg_panic("%s: null session cache type in new session callback",
 		  myname);
 
-    if (TLScontext->log_mask & TLS_LOG_CACHE)
-	/* serverid contains transport:addr:port information */
-	msg_info("save session %s to %s cache",
-		 TLScontext->serverid, TLScontext->cache_type);
-
-    /*
+    /*-
+     * Store only the first ticket for a given connection.
+     * - Even if the server offers multiple tickets, we have no mechanism to
+     *   store or use multiple concurrent tickets for the same nexthop.
+     *
      * Passivate and save the session object. Errors are non-fatal, since
      * caching is only an optimization.
      */
-    if ((session_data = tls_session_passivate(session)) != 0) {
+    if (TLScontext->ticketed == 0 &&
+	(session_data = tls_session_passivate(session)) != 0) {
+	TLScontext->ticketed = 1;
+	if (TLScontext->log_mask & TLS_LOG_CACHE)
+	    /* serverid contains transport:addr:port information */
+	    msg_info("save session %s to %s cache",
+		     TLScontext->serverid, TLScontext->cache_type);
+
 	tls_mgr_update(TLScontext->cache_type, TLScontext->serverid,
 		       STR(session_data), LEN(session_data));
 	vstring_free(session_data);
@@ -313,6 +319,7 @@ static void uncache_session(SSL_CTX *ctx, TLS_SESS_STATE *TLScontext)
 static void verify_x509(TLS_SESS_STATE *TLScontext, X509 *peercert,
 			        const TLS_CLIENT_START_PROPS *props)
 {
+    int     x509_err = SSL_get_verify_result(TLScontext->con);
 
     /*
      * On exit both peer_CN and issuer_CN should be set.
@@ -324,7 +331,7 @@ static void verify_x509(TLS_SESS_STATE *TLScontext, X509 *peercert,
      * Is the certificate trust chain trusted and matched?  Any required name
      * checks are now performed internally in OpenSSL.
      */
-    if (SSL_get_verify_result(TLScontext->con) == X509_V_OK) {
+    if (x509_err == X509_V_OK) {
 	TLScontext->peer_status |= TLS_CERT_FLAG_TRUSTED;
 	if (TLScontext->must_fail) {
 	    msg_panic("%s: cert valid despite trust init failure",
@@ -356,6 +363,13 @@ static void verify_x509(TLS_SESS_STATE *TLScontext, X509 *peercert,
 		tls_dane_log(TLScontext);
 	    }
 	}
+    } else if (TLS_MUST_MATCH(TLScontext->level) &&
+	       x509_err == X509_V_ERR_HOSTNAME_MISMATCH) {
+	/*
+	 * If the only error is a hostname mismatch, the certificate must have
+	 * been trusted.
+	 */
+	TLScontext->peer_status |= TLS_CERT_FLAG_TRUSTED;
     }
 
     /*
@@ -372,7 +386,6 @@ static void verify_x509(TLS_SESS_STATE *TLScontext, X509 *peercert,
 	    msg_info("%s: re-using session with untrusted peer credential, "
 		     "look for details earlier in the log", props->namaddr);
     }
-    /* TODO(wietse) Don't log TLSRPT success/failure for reused session. */
 }
 
 /* verify_rpk - process RFC7250 raw public key verification status */
@@ -417,7 +430,6 @@ static void verify_rpk(TLS_SESS_STATE *TLScontext, EVP_PKEY *peerpkey,
 	    msg_info("%s: re-using session with untrusted certificate, "
 		     "look for details earlier in the log", props->namaddr);
     }
-    /* TODO(wietse) Don't log TLSRPT success/failure for reused session. */
 }
 
 /* add_namechecks - tell OpenSSL what names to check */
@@ -846,34 +858,34 @@ TLS_APPL_STATE *tls_client_init(const TLS_CLIENT_INIT_PROPS *props)
     }
 
     /*
-     * Enable support for client->server raw public keys, provided we actually
-     * have keys to send.  They'll only be used if the server also enables
-     * client RPKs.
-     *
+     * Enable support for client->server raw public keys, provided we
+     * actually have keys to send.  They'll only be used if the server also
+     * enables client RPKs.
+     * 
      * XXX: When the server requests client auth, the TLS 1.2 protocol does not
      * provide an unambiguous mechanism for the client to not send an RPK (as
      * it can with client X.509 certs or TLS 1.3).  This is why we don't just
      * enable client RPK also with no keys in hand.
-     *
+     * 
      * A very unlikely scenario is that the server allows clients to not send
-     * keys, but only accepts keys for a set of algorithms we don't have.  Then
-     * we still can't send a key, but have agreed to RPK.  OpenSSL will attempt
-     * to send an empty RPK even with TLS 1.2 (and will accept such a message),
-     * but other implementations may be more strict.
-     *
+     * keys, but only accepts keys for a set of algorithms we don't have.
+     * Then we still can't send a key, but have agreed to RPK.  OpenSSL will
+     * attempt to send an empty RPK even with TLS 1.2 (and will accept such a
+     * message), but other implementations may be more strict.
+     * 
      * We could limit client RPK support to connections that support only TLS
      * 1.3 and up, but that's practical only decades in the future, and the
      * risk scenario is contrived and very unlikely.
      */
     if (SSL_CTX_get0_certificate(client_ctx) != NULL &&
-        SSL_CTX_get0_privatekey(client_ctx) != NULL)
-        tls_enable_client_rpk(client_ctx, NULL);
+	SSL_CTX_get0_privatekey(client_ctx) != NULL)
+	tls_enable_client_rpk(client_ctx, NULL);
 
     /*
      * With OpenSSL 1.0.2 and later the client EECDH curve list becomes
      * configurable with the preferred curve negotiated via the supported
-     * curves extension.  With OpenSSL 3.0 and TLS 1.3, the same applies
-     * to the FFDHE groups which become part of a unified "groups" list.
+     * curves extension.  With OpenSSL 3.0 and TLS 1.3, the same applies to
+     * the FFDHE groups which become part of a unified "groups" list.
      */
     tls_auto_groups(client_ctx, var_tls_eecdh_auto, var_tls_ffdhe_auto);
 
@@ -1422,14 +1434,19 @@ TLS_SESS_STATE *tls_client_post_connect(TLS_SESS_STATE *TLScontext,
     tls_int_seed();
 
     /*
-     * Inform the caller that we already reported a TLSRPT failure, so that
-     * the caller won't report success after a TLS level was degraded, or
-     * report some less informative failure reason after a more specific
-     * reason was already reported.
+     * Precondition: tls_client_start() is called only for a new TCP
+     * connection. It is never called for a reused TCP connection.
+     * 
+     * Inform the caller that they should not generate a TLSRPT 'success' or
+     * 'failure' event: either this TLS protocol engine has already generated
+     * a TLSRPT 'failure' event for this session, or this is a reused TLS
+     * session.
      */
 #ifdef USE_TLSRPT
-    TLScontext->rpt_reported = props->tlsrpt != 0 
-	&& trw_is_reported(props->tlsrpt);
+    TLScontext->rpt_reported = props->tlsrpt != 0
+	&& (trw_is_reported(props->tlsrpt)
+	    || (TLScontext->session_reused
+		&& trw_is_skip_reused_hs(props->tlsrpt)));
 #endif
 
     return (TLScontext);
